@@ -1,8 +1,8 @@
-# @(#)$Id: Informix.pm,v 100.4 2002/02/08 22:50:19 jleffler Exp $
+# @(#)$Id: Informix.pm,v 2007.2 2007/09/03 00:20:56 jleffler Exp $
 
 package Bundle::DBD::Informix;
 
-$VERSION = '2007.0826';
+$VERSION = '2007.0903';
 
 1;
 
@@ -18,11 +18,11 @@ C<perl -MCPAN -e 'install Bundle::DBD::Informix'>
 
 =head1 CONTENTS
 
-Digest::MD5  - Perl interface to the MD5 Algorithm by GAAS (Gisle Aas)
+Test::Pod      - Test for POD accuracy
 
-Time::HiRes  - High Resolution Timing by DEWEG (Douglas Wegscheid)
+Time::HiRes    - High Resolution Timing by DEWEG (Douglas Wegscheid)
 
-Bundle::DBI  - Bundle for DBI by TIMB (Tim Bunce)
+Bundle::DBI    - Bundle for DBI by TIMB (Tim Bunce)
 
 DBD::Informix  - DBD::Informix by JOHNL (Jonathan Leffler)
 
@@ -41,13 +41,6 @@ You could start by running:
     C<perl -MCPAN -e 'install Bundle::libnet'>
     C<perl -MCPAN -e 'install Bundle::LWP'>
 
-Note that DBD::Informix does not directly use Digest::MD5.  However, when
-Informix takes over support for DBD::Informix, then you may be required to
-demonstrate that the MD5 checksums of the code you've got match the
-original, or you'll be required to provide the diffs between the original
-and what you are using.  The shell script md5.verify and Perl script
-md5.check will be used to do this.
-
 DBD::Informix uses the Time::HiRes module for timing insert cursors.
 
 =head1 SEE ALSO
@@ -56,7 +49,7 @@ Bundle::DBI
 
 =head1 AUTHOR
 
-Jonathan Leffler E<lt>F<jleffler@informix.com>E<gt>
+Jonathan Leffler E<lt>F<jleffler@us.ibm.com>E<gt>
 
 =head1 THANKS
 
@@ -67,5 +60,6 @@ with some information from Jochen Wiedmann E<lt>F<joe@ispsoft.de>E<gt>.
   Copyright 1998-1999 Jonathan Leffler
   Copyright 2000      Informix Software Inc
   Copyright 2002      IBM
+  Copyright 2007      Jonathan Leffler
 
 =cut
